@@ -13,7 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from __future__ import print_function
+import itertools
 import os
+import six
 import sys
 import textwrap
 import uuid
@@ -21,12 +24,21 @@ import uuid
 import prettytable
 
 from ceilometerclient import exc
+from ceilometerclient.openstack.common import cliutils
 from ceilometerclient.openstack.common import importutils
+from ceilometerclient.openstack.common import strutils
 
 
 # Decorator for cli-args
 def arg(*args, **kwargs):
     def _decorator(func):
+        if 'help' in kwargs:
+            if 'default' in kwargs:
+                kwargs['help'] += " Defaults to %s." % kwargs['default']
+            required = kwargs.get('required', False)
+            if required:
+                kwargs['help'] += " Required."
+
         # Because of the sematics of decorator composition if we just append
         # to the options list positional options will appear to be backwards.
         func.__dict__.setdefault('arguments', []).insert(0, (args, kwargs))
@@ -39,43 +51,47 @@ def pretty_choice_list(l):
 
 
 def print_list(objs, fields, field_labels, formatters={}, sortby=0):
-    pt = prettytable.PrettyTable([f for f in field_labels],
-                                 caching=False, print_empty=False)
-    pt.align = 'l'
 
-    for o in objs:
-        row = []
-        for field in fields:
-            if field in formatters:
-                row.append(formatters[field](o))
-            else:
-                data = getattr(o, field, '')
-                row.append(data)
-        pt.add_row(row)
-    print pt.get_string(sortby=field_labels[sortby])
+    def _make_default_formatter(field):
+        return lambda o: getattr(o, field, '')
+
+    new_formatters = {}
+    for field, field_label in itertools.izip(fields, field_labels):
+        if field in formatters:
+            new_formatters[field_label] = formatters[field]
+        else:
+            new_formatters[field_label] = _make_default_formatter(field)
+
+    cliutils.print_list(objs, field_labels,
+                        formatters=new_formatters,
+                        sortby_index=sortby)
 
 
 def print_dict(d, dict_property="Property", wrap=0):
     pt = prettytable.PrettyTable([dict_property, 'Value'],
                                  caching=False, print_empty=False)
     pt.align = 'l'
-    for k, v in d.iteritems():
+    for k, v in sorted(six.iteritems(d)):
         # convert dict to str to check length
         if isinstance(v, dict):
             v = str(v)
-        if wrap > 0:
-            v = textwrap.fill(str(v), wrap)
+        if isinstance(v, six.string_types):
+            v = strutils.safe_encode(v)
         # if value has a newline, add in multiple rows
         # e.g. fault with stacktrace
-        if v and isinstance(v, basestring) and r'\n' in v:
+        if v and isinstance(v, six.string_types) and r'\n' in v:
             lines = v.strip().split(r'\n')
             col1 = k
             for line in lines:
+                if wrap > 0:
+                    line = textwrap.fill(str(line), wrap)
                 pt.add_row([col1, line])
                 col1 = ''
         else:
+            if wrap > 0:
+                v = textwrap.fill(str(v), wrap)
             pt.add_row([k, v])
-    print pt.get_string()
+    print(pt.get_string())
 
 
 def find_resource(manager, name_or_id):
@@ -142,7 +158,7 @@ def args_array_to_dict(kwargs, key_to_convert):
 
 def key_with_slash_to_nested_dict(kwargs):
     nested_kwargs = {}
-    for k in kwargs.keys():
+    for k in list(kwargs):
         keys = k.split('/', 1)
         if len(keys) == 2:
             nested_kwargs.setdefault(keys[0], {})[keys[1]] = kwargs[k]
@@ -151,7 +167,16 @@ def key_with_slash_to_nested_dict(kwargs):
     return kwargs
 
 
+def merge_nested_dict(dest, source, depth=0):
+    for (key, value) in six.iteritems(source):
+        if isinstance(value, dict) and depth:
+            merge_nested_dict(dest[key], value,
+                              depth=(depth - 1))
+        else:
+            dest[key] = value
+
+
 def exit(msg=''):
     if msg:
-        print >> sys.stderr, msg
+        print(msg, file=sys.stderr)
     sys.exit(1)
