@@ -10,12 +10,13 @@
 #   License for the specific language governing permissions and limitations
 #   under the License.
 
-import cStringIO
 import httplib2
 import re
+import six
 import sys
 
 import fixtures
+import mock
 from testtools import matchers
 
 from keystoneclient.v2_0 import client as ksclient
@@ -41,14 +42,14 @@ class ShellTest(utils.BaseTestCase):
 
     def setUp(self):
         super(ShellTest, self).setUp()
-        self.m.StubOutWithMock(ksclient, 'Client')
-        self.m.StubOutWithMock(v1client.Client, 'json_request')
-        self.m.StubOutWithMock(v1client.Client, 'raw_request')
 
-    def shell(self, argstr):
+    @mock.patch.object(ksclient, 'Client')
+    @mock.patch.object(v1client.Client, 'json_request')
+    @mock.patch.object(v1client.Client, 'raw_request')
+    def shell(self, argstr, mock_ksclient, mock_json, mock_raw):
         orig = sys.stdout
         try:
-            sys.stdout = cStringIO.StringIO()
+            sys.stdout = six.StringIO()
             _shell = ceilometer_shell.CeilometerShell()
             _shell.main(argstr.split())
         except SystemExit:
