@@ -35,7 +35,8 @@ del CREATE_SAMPLE['message_id']
 del CREATE_SAMPLE['source']
 
 base_url = '/v2/meters/instance'
-args = 'q.op=&q.op=&q.value=foo&q.value=bar&q.field=resource_id&q.field=source'
+args = 'q.field=resource_id&q.field=source&q.op=&q.op=&q.value=foo&q.value=bar'
+args_limit = 'limit=1'
 fixtures = {
     base_url:
     {
@@ -54,6 +55,13 @@ fixtures = {
             {},
             [],
         ),
+    },
+    '%s?%s' % (base_url, args_limit):
+    {
+        'GET': (
+            {},
+            [GET_SAMPLE]
+        ),
     }
 }
 
@@ -93,3 +101,9 @@ class SampleManagerTest(utils.BaseTestCase):
         ]
         self.assertEqual(self.api.calls, expect)
         self.assertTrue(sample)
+
+    def test_limit(self):
+        samples = list(self.mgr.list(meter_name='instance', limit=1))
+        expect = [('GET', '/v2/meters/instance?limit=1', {}, None)]
+        self.assertEqual(self.api.calls, expect)
+        self.assertEqual(len(samples), 1)
