@@ -23,7 +23,8 @@ class Statistics(base.Resource):
 class StatisticsManager(base.Manager):
     resource_class = Statistics
 
-    def list(self, meter_name, q=None):
+    def list(self, meter_name, q=None, period=None):
+        p = ['period=%s' % period] if period else None
         return self._list(options.build_url(
             '/v2/meters/' + meter_name + '/statistics',
-            q))
+            q, p))
